{#
    categories.html
    ~~~~~~~~~~~~~~~

    Sidebar list of all categories.

    :copyright: Copyright 2012 by Iñigo Serna
    :license: FreeBSD, see LICENSE file
#}


<div class="widget">
    <h3>{{ text_categories }}</h3>
    <ul>
      {%- for category, count in categories|dictsort %}
        <li><a href="{{ pathto('categories/' + catlinks[category]) }}">{{ category }}</a> ({{ count }})</li>
      {%- endfor %}
    </ul>
</div>
