{#-
    boilerplate/recent.html
    ~~~~~~~~~~~~~~~~~~~~~~~

    Sidebar list of recent posts.

    :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
    CONTRIBUTORS file)
    :license: FreeBSD, see LICENSE file
-#}

{%- set recent_count = recent_count is not defined and 10 or recent_count -%}

<div class="widget">
    <h1>Recent Posts</h1>
    <ul>
        {%- for post, post_title in recent[:recent_count] -%}
        <li>
            <a href="{{ pathto(post) }}">{{ post_title }}</a>
        </li>
        {%- endfor -%}
    </ul>
</div>

