/*
 * webfont.css
 * ~~~~~~~~~~~
 * 
 * Stylesheet defining WebFont font face.
 *
 * :copyright: Copyright 2011-2012 by Vlad Riscutia and contributors (see
 * CONTRIBUTORS file)
 * :license: FreeBSD, see LICENSE file
 */

/* WebFont ----------------------------------------------------------------- */
@font-face {
    font-family: "WebSymbolsRegular";
    src: url("websymbols-regular-webfont.eot");
    src: url("websymbols-regular-webfont.eot?#iefix") format("embedded-opentype"),
         url("websymbols-regular-webfont.woff") format("woff"),
         url("websymbols-regular-webfont.ttf") format("truetype"),
         url("websymbols-regular-webfont.svg#WebSymbolsRegular") format("svg");
    font-weight: normal;
    font-style: normal;
}

.webfont {
    font-family: WebSymbolsRegular;
    font-weight: normal;
    font-style: normal;
}

